==> spectrapepper-0.1.3.tar.gz: spectrapepper-0.1.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""

import io
from os import path as op
from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

here = op.abspath(op.dirname(__file__))

# get the dependencies and installs
with io.open(op.join(here, "requirements.txt"), encoding="utf-8") as f:
    all_reqs = f.read().split("\n")

install_requires = [x.strip() for x in all_reqs if "git+" not in x]
dependency_links = [x.strip().replace("git+", "") for x in all_reqs if "git+" not in x]

requirements = [ ]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="spectrapepper",
    author_email='spectrapepper@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="A Python package to simplify and accelerate analysis of spectroscopy data",
    install_requires=install_requires,
    dependency_links=dependency_links,
    license="MIT license",
    long_description=readme,
    long_description_content_type='text/markdown',
    include_package_data=True,
    keywords='spectrapepper',
    name='spectrapepper',
    packages=find_packages(include=['spectrapepper', 'spectrapepper.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/spectrapepper/spectrapepper',
    version='0.1.3',
    zip_safe=False,
    package_data={'spectrapepper': ['datasets/headers.txt',
                                    'datasets/mapping1.txt',
                                    'datasets/mapping2.txt',
                                    'datasets/params.txt',
                                    'datasets/spectras.txt',
                                    'datasets/targets.txt']}
)

==> spectrapepper-0.1.6.tar.gz: spectrapepper-0.1.6/setup.py <==
#!/usr/bin/env python

"""The setup script."""

import io
from os import path as op
from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

here = op.abspath(op.dirname(__file__))

# get the dependencies and installs
with io.open(op.join(here, "requirements.txt"), encoding="utf-8") as f:
    all_reqs = f.read().split("\n")

install_requires = [x.strip() for x in all_reqs if "git+" not in x]
dependency_links = [x.strip().replace("git+", "") for x in all_reqs if "git+" not in x]

requirements = [ ]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="spectrapepper",
    author_email='spectrapepper@gmail.com',
    python_requires='>=3.7',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        #'Programming Language :: Python :: 3.5',
        #'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ],
    description="A Python package to simplify and accelerate analysis of spectroscopy data",
    install_requires=install_requires,
    dependency_links=dependency_links,
    license="MIT license",
    long_description=readme,
    long_description_content_type='text/markdown',
    include_package_data=True,
    keywords='spectrapepper',
    name='spectrapepper',
    packages=find_packages(include=['spectrapepper', 'spectrapepper.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/spectrapepper/spectrapepper',
    version='0.1.6',
    zip_safe=False,
    package_data={'spectrapepper': ['datasets/headers.txt',
                                    'datasets/mapping1.txt',
                                    'datasets/mapping2.txt',
                                    'datasets/params.txt',
                                    'datasets/spectras.txt',
                                    'datasets/targets.txt']}
)
